@@ -1,4 +1,4 @@
-__version__ = "0.3.9"
+__version__ = "1.0.1"
 
 from scrapingant_client.client import ScrapingAntClient
 from scrapingant_client.cookie import Cookie
@@ -9,6 +9,7 @@ from scrapingant_client.errors import (
     ScrapingantInternalException,
     ScrapingantSiteNotReachableException,
     ScrapingantDetectedException,
+    ScrapingantTimeoutException,
 )
 from scrapingant_client.proxy_type import ProxyType
 from scrapingant_client.response import Response
@@ -23,5 +24,6 @@ __all__ = [
     'ScrapingantInternalException',
     'ScrapingantSiteNotReachableException',
     'ScrapingantDetectedException',
+    'ScrapingantTimeoutException',
     'Response',
 ]
